package de.uka.ipd.sdq.simucomframework.abstractSimEngine;

/**
 * Represents a type identification for failure-on-demand occurrences during the
 * simulation.
 * 
 * @author brosch
 * 
 */
public abstract class SimFailureType {

	/**
	 * The ID of this failure type.
	 * 
	 * The ID is unique across all failure types in a simulation run.
	 */
	private String id;

	/**
	 * The human-readable name of this failure type.
	 */
	private String name;

	/**
	 * The constructor.
	 * 
	 * @param id
	 *            the ID of this failure type
	 * @param name
	 *            the name of this failure type.
	 */
	public SimFailureType(final String id, final String name) {
		this.id = id;
		this.name = name;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	public boolean equals(Object obj) {

		// The equality test is based on the ID attribute:
		return (this.getClass().equals(obj.getClass()))
				&& (this.getId().equals(((SimFailureType) obj).getId()));
	}

	/**
	 * Retrieves the ID of this failure type.
	 * 
	 * @return the ID of this failure type
	 */
	public String getId() {
		return id;
	}

	/**
	 * Retrieves a name of this failure type.
	 * 
	 * The name is used for describing the failure type in the simulation result
	 * data.
	 * 
	 * @return the name of this failure type.
	 */
	public String getName() {
		return name;
	}
}
