package de.uka.ipd.sdq.simucomframework.abstractSimEngine;

/**
 * Represents a failure type for a failure-on-demand occurrence due to a timeout
 * requesting a passive resource.
 * 
 * @author brosch
 * 
 */
public class SimResourceTimeoutFailureType extends SimFailureType {

	/**
	 * The ID of the component instance containing the passive resource, as
	 * specified through an AssemblyContext in a PCM System model.
	 */
	private String assemblyContextId;

	/**
	 * The resource ID, as specified for a PassiveResource in a PCM Repository
	 * model.
	 */
	private String passiveResourceId;

	/**
	 * The constructor.
	 * 
	 * @param assemblyContextId
	 *            the ID of the component instance containing the passive
	 *            resource, as specified through an AssemblyContext in a PCM
	 *            System model
	 * @param assemblyContextName
	 *            the name of the component instance containing the passive
	 *            resource, as specified through an AssemblyContext in a PCM
	 *            System model
	 * @param passiveResourceId
	 *            the resource ID, as specified through a PassiveResource in a
	 *            PCM Repository model
	 * @param passiveResourceName
	 *            the resource name, as specified through a PassiveResource in a
	 *            PCM Repository model
	 */
	public SimResourceTimeoutFailureType(final String assemblyContextId,
			final String assemblyContextName, final String passiveResourceId,
			final String passiveResourceName) {
		super(assemblyContextId + "/" + passiveResourceId, assemblyContextName
				+ "/" + passiveResourceName
				+ " (passive resource timeout failure)");
		this.assemblyContextId = assemblyContextId;
		this.passiveResourceId = passiveResourceId;
	}

	/**
	 * Retrieves the passive resource ID.
	 * 
	 * @return the passive resource ID
	 */
	public String getPassiveResourceId() {
		return passiveResourceId;
	}

	/**
	 * Retrieves the assembly context ID.
	 * 
	 * @return the assembly context ID
	 */
	public String getAssemblyContextId() {
		return assemblyContextId;
	}
}
